==> Evergreen-ILS-3.14.7.tar.gz: Evergreen-ILS-3.14.7/Open-ILS/web/js/dojo/openils/circ/nls/pt-br/selfcheck.js <==
{
    ":TOTAL_ITEMS_SESSION": "Total items this session: ${0}.",
    ":TOTAL_ITEMS_ACCOUNT": "Total items on account:  ${0}.",
    ":HOLDS_READY_FOR_PICKUP": "You have ${0} item(s) ready for pickup.",
    ":TOTAL_HOLDS": "You have ${0} total holds.",
    ":TOTAL_FINES_ACCOUNT": "Total fines on account: $${0}.",
    ":HOLD_STATUS_READY": "Pronto para Coletar",
    ":HOLD_STATUS_WAITING": "#${0} de acordo com ${1} exemplares",
    ":CHECKOUT_SUCCESS": "Empr\u00e9stimo do item ${0} realizado com sucesso",
    ":RENEW_SUCCESS": "Renova\u00e7\u00e3o do item ${0} realizada com sucesso",
    ":ALREADY_OUT": "Item ${0} j\u00e1 est\u00e1 emprestado",
    ":OPEN_CIRCULATION_EXISTS": "O item ${0} j\u00e1 est\u00e1 emprestado a outro usu\u00e1rio",
    ":GENERIC_CIRC_FAILURE": "N\u00e3o foi poss\u00edvel emprestar o item ${0}. Favor contatar a administra\u00e7\u00e3o.",
    ":LOGIN_FAILED": "Login para ${0} falhou",
    ":UNKNOWN_ERROR": "Uma exce\u00e7\u00e3o n\u00e3o tratada ocorreu com c\u00f3digo de erro ${0}",
    ":MAX_RENEWALS": "N\u00e3o \u00e9 permitido realizar mais renova\u00e7\u00f5es do item ${0}",
    ":ITEM_NOT_CATALOGED": "item de ${0} n\u00e3o foi encontrado no sistema. Tente re-entrar o item.",
    ":WORKSTATION_REQUIRED": "Uma esta\u00e7\u00e3o de trabalho \u00e9 necess\u00e1ria para entrar em AutoAtendimento. Voc\u00ea pode definir o nome da esta\u00e7\u00e3o de trabalho com param URL 'ws'.\n\nGostaria de registrar uma nova esta\u00e7\u00e3o de trabalho para essa interface de auto-atendimento?",
    ":WORKSTATION_EXISTS": "Esta esta\u00e7\u00e3o de trabalho j\u00e1 foi registrada. Gostaria de us\u00e1-la como esta\u00e7\u00e3o de auto empr\u00e9stimo?",
    ":CC_PAYABLE_BALANCE": "Valor total a pagar: $${0}",
    ":TOTAL_FINES_SELECTED": "Total selecionado: $${0}",
    ":WELCOME_BANNER": "Bem-vindo, ${0}",
    ":ENTER_PASSWORD": "Please enter your password",
    ":PLEASE_LOGIN": "Please log in with your username or library barcode.",
    ":ENTER_BARCODE": "Please enter an item barcode",
    ":MISCELLANEOUS": "Miscellaneous",
    ":FAIL_PART_actor_usr_barred": "O usu\u00e1rio esta barrado",
    ":FAIL_PART_asset_copy_circulate": "O item n\u00e3o circula",
    ":FAIL_PART_asset_copy_location_circulate": "Itens desta localiza\u00e7\u00e3o nas prateleiras n\u00e3o circulam",
    ":FAIL_PART_asset_copy_status": "O item n\u00e3o pode circular neste momento",
    ":FAIL_PART_circ_holds_target_skip_me": "A biblioteca de circula\u00e7\u00e3o deste item n\u00e3o atende reservas",
    ":FAIL_PART_config_circ_matrix_circ_mod_test": "O usu\u00e1rio esta com itens demais deste tipo emprestados",
    ":FAIL_PART_config_circ_matrix_test_available_copy_hold_ratio": "O n\u00edvel de itens dispon\u00edveis para reserva est\u00e1 muito baixo",
    ":FAIL_PART_config_circ_matrix_test_circulate": "Regras de circula\u00e7\u00e3o rejeitaram este item como n\u00e3o circul\u00e1vel",
    ":FAIL_PART_config_circ_matrix_test_total_copy_hold_ratio": "O n\u00edvel total de itens dispon\u00edveis para empr\u00e9stimo esta baixo",
    ":FAIL_PART_config_hold_matrix_test_holdable": "Regras de reserva rejeitaram este item como n\u00e3o reserv\u00e1vel",
    ":FAIL_PART_config_hold_matrix_test_max_holds": "O cliente atingiu o n\u00famero m\u00e1ximo de reservas",
    ":FAIL_PART_item.holdable": "O item n\u00e3o \u00e9 reserv\u00e1vel",
    ":FAIL_PART_location.holdable": "A localiza\u00e7\u00e3o de um item n\u00e3o \u00e9 reserv\u00e1vel",
    ":FAIL_PART_status.holdable": "A situa\u00e7\u00e3o do  item n\u00e3o permite reservar",
    ":FAIL_PART_config_rule_age_hold_protect_prox": "O item \u00e9 muito novo para transitar nesta dist\u00e2ncia",
    ":FAIL_PART_no_item": "O sistema n\u00e3o p\u00f4de encontrar este item",
    ":FAIL_PART_no_ultimate_items": "O sistema n\u00e3o encontrou nenhum item que corresponda \u00e0 esta solicita\u00e7\u00e3o de reserva",
    ":FAIL_PART_monographic_part_required": "Title hold request invalid when monographic part required",
    ":FAIL_PART_no_matchpoint": "As regras do sistema n\u00e3o definem como manipular este item",
    ":FAIL_PART_no_user": "O sistema n\u00e3o conseguiu encontrar este usu\u00e1rio",
    ":FAIL_PART_transit_range": "Este item n\u00e3o pode transitar para esta dist\u00e2ncia",
    ":PAYMENT_INVALID_USER_XACT_ID": "N\u00e3o podemos prosseguir com o pagamento, pois sua conta foi atualizada a partir de outra localiza\u00e7\u00e3o. Por favor, atualize a interface ou relogue para receber as informa\u00e7\u00f5es mais recentes da conta."
}

==> Evergreen-ILS-3.16.0.tar.gz: Evergreen-ILS-3.16.0/Open-ILS/web/js/dojo/openils/circ/nls/pt-br/selfcheck.js <==
{
    ":TOTAL_ITEMS_SESSION": "Total de itens desta sess\u00e3o: <b>${0}</b>.",
    ":TOTAL_ITEMS_ACCOUNT": "Total de itens na conta:  <b>${0}</b>.",
    ":HOLDS_READY_FOR_PICKUP": "Voc\u00ea tem  <b>${0}</b> itens dispon\u00edveis para retirar.",
    ":TOTAL_HOLDS": "Voc\u00ea possui um total de <b>${0}</b> empr\u00e9stimos.",
    ":TOTAL_FINES_ACCOUNT": "Total de multas na conta: <b>$${0}</b>.",
    ":HOLD_STATUS_READY": "Pronto para Coletar",
    ":HOLD_STATUS_WAITING": "#${0} de acordo com ${1} exemplares",
    ":CHECKOUT_SUCCESS": "Empr\u00e9stimo do item ${0} realizado com sucesso",
    ":RENEW_SUCCESS": "Renova\u00e7\u00e3o do item ${0} realizada com sucesso",
    ":ALREADY_OUT": "Item ${0} j\u00e1 est\u00e1 emprestado",
    ":OPEN_CIRCULATION_EXISTS": "O item ${0} j\u00e1 est\u00e1 emprestado a outro usu\u00e1rio",
    ":GENERIC_CIRC_FAILURE": "N\u00e3o foi poss\u00edvel emprestar o item ${0}. Favor contatar a administra\u00e7\u00e3o.",
    ":LOGIN_FAILED": "Login para ${0} falhou",
    ":UNKNOWN_ERROR": "Uma exce\u00e7\u00e3o n\u00e3o tratada ocorreu com c\u00f3digo de erro ${0}",
    ":MAX_RENEWALS": "N\u00e3o \u00e9 permitido realizar mais renova\u00e7\u00f5es do item ${0}",
    ":ITEM_NOT_CATALOGED": "item de ${0} n\u00e3o foi encontrado no sistema. Tente re-entrar o item.",
    ":WORKSTATION_REQUIRED": "Uma esta\u00e7\u00e3o de trabalho \u00e9 necess\u00e1ria para entrar em AutoAtendimento. Voc\u00ea pode definir o nome da esta\u00e7\u00e3o de trabalho com param URL 'ws'.\n\nGostaria de registrar uma nova esta\u00e7\u00e3o de trabalho para essa interface de auto-atendimento?",
    ":WORKSTATION_EXISTS": "Esta esta\u00e7\u00e3o de trabalho j\u00e1 foi registrada. Gostaria de us\u00e1-la como esta\u00e7\u00e3o de auto empr\u00e9stimo?",
    ":CC_PAYABLE_BALANCE": "Valor total a pagar: $${0}",
    ":TOTAL_FINES_SELECTED": "Total selecionado: $${0}",
    ":WELCOME_BANNER": "Bem-vindo, ${0}",
    ":ENTER_PASSWORD": "Please enter your password",
    ":PLEASE_LOGIN": "Please log in with your username or library barcode.",
    ":ENTER_BARCODE": "Please enter an item barcode",
    ":MISCELLANEOUS": "Miscellaneous",
    ":FAIL_PART_actor_usr_barred": "O usu\u00e1rio esta barrado",
    ":FAIL_PART_asset_copy_circulate": "O item n\u00e3o circula",
    ":FAIL_PART_asset_copy_location_circulate": "Itens desta localiza\u00e7\u00e3o nas prateleiras n\u00e3o circulam",
    ":FAIL_PART_asset_copy_status": "O item n\u00e3o pode circular neste momento",
    ":FAIL_PART_circ_holds_target_skip_me": "A biblioteca de circula\u00e7\u00e3o deste item n\u00e3o atende reservas",
    ":FAIL_PART_config_circ_matrix_circ_mod_test": "O usu\u00e1rio esta com itens demais deste tipo emprestados",
    ":FAIL_PART_config_circ_matrix_test_available_copy_hold_ratio": "O n\u00edvel de itens dispon\u00edveis para reserva est\u00e1 muito baixo",
    ":FAIL_PART_config_circ_matrix_test_circulate": "Regras de circula\u00e7\u00e3o rejeitaram este item como n\u00e3o circul\u00e1vel",
    ":FAIL_PART_config_circ_matrix_test_total_copy_hold_ratio": "O n\u00edvel total de itens dispon\u00edveis para empr\u00e9stimo esta baixo",
    ":FAIL_PART_config_hold_matrix_test_holdable": "Regras de reserva rejeitaram este item como n\u00e3o reserv\u00e1vel",
    ":FAIL_PART_config_hold_matrix_test_max_holds": "O cliente atingiu o n\u00famero m\u00e1ximo de reservas",
    ":FAIL_PART_item.holdable": "O item n\u00e3o \u00e9 reserv\u00e1vel",
    ":FAIL_PART_location.holdable": "A localiza\u00e7\u00e3o de um item n\u00e3o \u00e9 reserv\u00e1vel",
    ":FAIL_PART_status.holdable": "A situa\u00e7\u00e3o do  item n\u00e3o permite reservar",
    ":FAIL_PART_config_rule_age_hold_protect_prox": "O item \u00e9 muito novo para transitar nesta dist\u00e2ncia",
    ":FAIL_PART_no_item": "O sistema n\u00e3o p\u00f4de encontrar este item",
    ":FAIL_PART_no_ultimate_items": "O sistema n\u00e3o encontrou nenhum item que corresponda \u00e0 esta solicita\u00e7\u00e3o de reserva",
    ":FAIL_PART_monographic_part_required": "Title hold request invalid when monographic part required",
    ":FAIL_PART_no_matchpoint": "As regras do sistema n\u00e3o definem como manipular este item",
    ":FAIL_PART_no_user": "O sistema n\u00e3o conseguiu encontrar este usu\u00e1rio",
    ":FAIL_PART_transit_range": "Este item n\u00e3o pode transitar para esta dist\u00e2ncia",
    ":PAYMENT_INVALID_USER_XACT_ID": "N\u00e3o podemos prosseguir com o pagamento, pois sua conta foi atualizada a partir de outra localiza\u00e7\u00e3o. Por favor, atualize a interface ou relogue para receber as informa\u00e7\u00f5es mais recentes da conta."
}
